"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.outputFile = exports.ensureDirSync = void 0;
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const checkPath = (pth) => {
    if (process.platform === 'win32') {
        const pathHasInvalidWinCharacters = /[<>:"|?*]/.test(pth.replace(path_1.default.parse(pth).root, ''));
        if (pathHasInvalidWinCharacters) {
            const error = new Error(`Path contains invalid characters: ${pth}`);
            throw error;
        }
    }
};
const getMode = (options) => {
    const defaults = { mode: 0o777 };
    if (typeof options === 'number')
        return options;
    return Object.assign(Object.assign({}, defaults), options).mode;
};
const ensureDirSync = (dir, options) => {
    checkPath(dir);
    return fs_1.default.mkdirSync(dir, {
        mode: getMode(options),
        recursive: true,
    });
};
exports.ensureDirSync = ensureDirSync;
const outputFile = (filePath, fileContent) => {
    const output = path_1.default.resolve(filePath);
    const folderPath = path_1.default.parse(output);
    (0, exports.ensureDirSync)(folderPath.dir);
    fs_1.default.writeFileSync(output, fileContent);
    console.log(`output file: ${output}`);
};
exports.outputFile = outputFile;
